diff -u --recursive --new-file --exclude=zImage --exclude=config.ini --exclude='.*' --exclude='*.patch' --exclude=buildit --exclude=defconfig empeg.v356.orig/arch/arm/special/hijack.c empeg.v356/arch/arm/special/hijack.c
--- empeg.v356.orig/arch/arm/special/hijack.c	Sat Jan 24 22:56:36 2004
+++ empeg.v356/arch/arm/special/hijack.c	Sun Jan 25 13:06:12 2004
@@ -60,6 +60,7 @@
 int	hijack_reboot = 0;		// set to "1" to cause reboot on next display refresh
 pid_t	hijack_player_init_pid;		// used in fs/read_write.c, fs/exec.c
 unsigned int hijack_player_started = 0;	// set to jiffies when player startup is detected on serial port (notify.c)
+unsigned char * player_buffer;
 
 static unsigned int PROMPTCOLOR = COLOR3, ENTRYCOLOR = -COLOR3;
 
@@ -3937,6 +3938,8 @@
 	unsigned long flags;
 	int refresh = NEED_REFRESH;
 
+	player_buffer = player_buf;
+
 	if (hijack_reboot) {
 		do_reboot(dev);
 		return;
@@ -4704,6 +4707,23 @@
 			userland_display_updated = 1;
 			return 0;
 		}
+		case EMPEG_HIJACK_GETPLAYERBUFFER:	// get the contents of the player's screen
+		{
+			// Invocation:  rc = ioctl(fd, EMPEG_HIJACK_GETPLAYERBUFFER, (char *)&buf);
+			
+			if(copy_to_user((char *) arg, player_buffer, EMPEG_SCREEN_BYTES))
+				return -EFAULT;
+			else
+				return 0;
+
+		}
+		case EMPEG_HIJACK_GETPLAYERUIFLAGS:	// return the player UI status
+		{
+			// Invocation:  rc = ioctl(fd, EMPEG_HIJACK_GETPLAYERUIFLAGS, (unsigned long *)&data);
+			unsigned int ui_flags = get_player_ui_flags (player_buffer);
+			return put_user(ui_flags, (unsigned int *)arg);
+
+		}
 		case EMPEG_HIJACK_READ_GPLR:	// read GPSR
 		{
 			//
diff -u --recursive --new-file --exclude=zImage --exclude=config.ini --exclude='.*' --exclude='*.patch' --exclude=buildit --exclude=defconfig empeg.v356.orig/include/asm-arm/arch-sa1100/hijack.h empeg.v356/include/asm-arm/arch-sa1100/hijack.h
--- empeg.v356.orig/include/asm-arm/arch-sa1100/hijack.h	Thu Sep 25 16:07:49 2003
+++ empeg.v356/include/asm-arm/arch-sa1100/hijack.h	Sun Jan 25 00:34:06 2004
@@ -64,6 +64,8 @@
 #define EMPEG_HIJACK_SETGEOM		_IO(EMPEG_DISPLAY_MAGIC, 88)	// Set screen overlay geometry
 #define EMPEG_HIJACK_POLLBUTTONS	_IO(EMPEG_DISPLAY_MAGIC, 89)	// Read next IR code; EBUSY if none available
 #define EMPEG_HIJACK_INJECTBUTTONS	_IO(EMPEG_DISPLAY_MAGIC, 90)	// Inject button codes into player's input queue
+#define EMPEG_HIJACK_GETPLAYERBUFFER	_IO(EMPEG_DISPLAY_MAGIC, 91)	// Inject button codes into player's input queue
+#define EMPEG_HIJACK_GETPLAYERUIFLAGS	_IO(EMPEG_DISPLAY_MAGIC, 92)	// Inject button codes into player's input queue
 #define EMPEG_HIJACK_READ_GPLR		_IO(EMPEG_DISPLAY_MAGIC, 0xa0)	// Read state of serial port flow control pins (and other stuff)
 #define EMPEG_HIJACK_TUNER_SEND		_IO(EMPEG_DISPLAY_MAGIC, 0xee)	// Send bytestring to Tuner.  First byte is bytecount.
 
